@@ -24,20 +24,8 @@ using namespace pqxx;
 // The program will attempt to add an entry to a table called "events",
 // with a key column called "year"--and then abort the change.
 
-
-// Function to print database's warnings  to cerr
 namespace
 {
-
-extern "C"
-{
-void ReportWarning(void *, const char msg[])
-{
-  cerr << msg;
-}
-}
-
-
 // Let's take a boring year that is not going to be in the "events" table
 const int BoringYear = 1977;
 
@@ -164,7 +152,6 @@ int main(int, char *argv[])
   try
   {
     Connection C(argv[1] ? argv[1] : "");
-    C.SetNoticeProcessor(ReportWarning, 0);
 
     // Test abort semantics, both with explicit and implicit abort
     Test(C, true);
